Learn R Programming

MonoPoly (version 0.3-10)

hawkins: hawkins

Description

This data gives x and y variables for the data published in Hawkins' 1994 article. This data was originally simulated from a standard cubic polynomial with equally spaced x values between -1 and 1.

Arguments

Format

A data frame with 50 simulated observations on the following 2 variables.

y

a numeric vector

x

a numeric vector

Examples

Run this code
# NOT RUN {
data(hawkins)
# }

Run the code above in your browser using DataLab