Learn R Programming

MonoPoly (version 0.3-10)

ismonotone: Check whether a polynomial is monotone

Description

Function to check whether a polynomial is montone over a given interval.

Usage

ismonotone(object, …)

# S3 method for monpol ismonotone(object, a = -Inf, b = Inf, EPS = 1e-06, …)

# S3 method for default ismonotone(object, a = -Inf, b = Inf, EPS = 1e-06, …)

Arguments

object

Either an object of class ‘

monpol
’ or a numeric vector containing the coefficient of the polynomial.

a

Lower limit of the interval over which the polynomial should be montone.

b

Upper limit of the interval over which the polynomial should be montone.

EPS

Numerical precision, values with absolute value smaller than EPS are treated as zero.

Further arguments passed to or from other methods.

Value

TRUE or FALSE depending on whether the polynomial is montone over (a,b) or not.

Note that due to numerical precision issues it is possible that a polynomial that should be monotone is declared to be not monotone.

Examples

Run this code
# NOT RUN {
  fit <- monpol(y~x, w0)
  ismonotone(fit)

  beta <- c(1,0,2)  ## the polynomial 1 + 2*x^2
  ismonotone(beta)
  ismonotone(beta, a=0)
  ismonotone(beta, b=0)
# }

Run the code above in your browser using DataLab