residuals.monpol: Extract Model Residuals
Description
residuals method for ‘monpol’ objects.
Usage
# S3 method for monpol
residuals(object, scale = c("original", "fitted"), …)Arguments
scale
Extract residuals on the original scale of the data
or on the scale used during fitting.
…
Additional optionals arguments. At present no optional
arguments are used.
Value
Residuals extracted from the model object object.
Details
This is the residuals method for objects inheriting from
class "monpol".