Learn R Programming

MonoPoly (version 0.2-8)

residuals.monpol: Extract Model Residuals

Description

residuals method for monpol objects.

Usage

## S3 method for class 'monpol':
residuals(object, scale = c("original", "fitted"), ...)

Arguments

object
A monpol object.
scale
Extract residuals on the original scale of the data or on the scale used during fitting.
...
Additional optionals arguments. At present no optional arguments are used.

Value

  • Residuals extracted from the model object object.

Details

This is the residuals method for objects inheriting from class "monpol".